#[non_exhaustive]pub enum VersionFileError {
FileNotFound(PathBuf),
NoVersionField,
WriteFailed(Error),
ReadFailed(Error),
InvalidRegex(String),
}Expand description
Errors that can occur when reading or writing version files.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FileNotFound(PathBuf)
The expected file was not found on disk.
NoVersionField
The file does not contain a version field this engine can handle.
WriteFailed(Error)
Writing the updated content back to disk failed.
ReadFailed(Error)
Reading the file from disk failed.
InvalidRegex(String)
A user-supplied regex pattern is invalid or has no capture groups.